#!/usr/bin/env python3

"""
Criticality: Normal
Checks that the webserver is running.
"""

from pathlib import Path
import requests
import sys

sys.path.append(str(Path(__file__).parents[1].resolve()))

# pylint: disable=wrong-import-position
from utilities import logging as lg  # noqa: E402


def main():
    print("Checking nginx status:")

    if not Path("/etc/nginx").exists():
        lg.info("nginx dir does not exists, skip test")
        exit(2)

    try:
        req = requests.get(
            "http://127.0.0.1:1080/nginx_status",
            proxies={"http": "", "https": ""},
            timeout=5,
        )
        if req.status_code != 200:
            raise Exception("status code: {}".format(req.status_code))
        if "Active connections" not in req.text:
            raise Exception("invalid response from nginx status url")
    except Exception as e:
        lg.error(str(e))
        exit(1)

    lg.success("status code: {}".format(req.status_code))
    exit(0)


if __name__ == "__main__":
    main()
